# *portrait*

Observation metrics for periodic events

---

A Python package to compute and visualize observation metrics for periodic events. In Astronomy, *portrait* is useful to answer the following questions:
- How much of an orbit with period $P$ has been observed given certain observation times? ([tutorial](coverage))
- What period $P$ matches with this list of events? ([tutorial](periodmatch))
- How a certain target must be observed to cover all orbits with periods lower than $P$ days? 

## Table of content
```{toctree}
:maxdepth: 0
:caption: Get started

installation.md
acknowledgement
```

```{toctree}
:maxdepth: 0
:caption: Tutorials

periodmatch
coverage
tess
```

```{toctree}
:maxdepth: 0
:caption: Reference

api.rst
```

